/// <reference types="koa-bodyparser" />
/// <reference types="koa__router" />
import * as Router from '@koa/router';
import { ClassConstructor } from 'class-transformer';
import * as Koa from 'koa';
export declare enum ERouteControllerActionPayload {
    QUERY = "query",
    BODY = "body",
    PATH = "path"
}
export declare enum ERouteControllerActionMethod {
    GET = "get",
    POST = "post",
    DELETE = "delete"
}
export interface IResponseBodyError {
    code: number;
    message: string;
    details?: Record<string, any>;
}
export interface IResponseBody<Data = Record<string, any>> {
    data?: Data;
    error?: IResponseBodyError;
}
export interface IContextState<DTO> extends Koa.DefaultState {
    dto: DTO;
}
export declare type TMiddleware<DTO = Record<string, any>> = Koa.Middleware<IContextState<DTO>, Koa.DefaultContext & {
    params: Record<string, string>;
}, IResponseBody>;
export declare type TRequestContext<RequestDTO, ResponseDTO extends TResponseDTO> = Koa.ParameterizedContext<IContextState<RequestDTO>, Koa.DefaultContext, ResponseDTO['body']>;
export declare type TResponseDTO<Body = any> = {
    status: number;
    body: IResponseBody<Body> | void;
};
export declare type TRequestDTO = Record<string, any>;
export declare type TRouteControllerActionHandler<RequestDTO extends TRequestDTO, ResponseDTO extends TResponseDTO> = (app: Koa) => (ctx: TRequestContext<RequestDTO, ResponseDTO>) => Promise<ResponseDTO['body'] extends Record<any, any> ? ResponseDTO['body']['data'] : void>;
export declare type TRouteControllerAction<RequestDTO extends TRequestDTO, ResponseDTO extends TResponseDTO> = {
    path: string;
    method: ERouteControllerActionMethod;
    payload: ERouteControllerActionPayload[];
    Handler: TRouteControllerActionHandler<RequestDTO, ResponseDTO>;
    RequestDTO: ClassConstructor<any>;
    ResponseDTO: ClassConstructor<any>;
};
export interface IRouteController {
    path: string;
    actions: (IRouteController | TRouteControllerAction<any, any>)[];
}
export declare function getControllerActionRouter<RequestDTO extends TRequestDTO, ResponseDTO extends TResponseDTO>(app: Koa, action: TRouteControllerAction<RequestDTO, ResponseDTO>): Router;
export declare function registerControllerRoutes(app: Koa, controller: IRouteController, mainRouter: Router, path?: string): void;
export declare function getApplicationRouter(app: Koa, controllers: IRouteController[]): Router;
