"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getApplicationRouter = exports.registerControllerRoutes = exports.getControllerActionRouter = exports.ERouteControllerActionMethod = exports.ERouteControllerActionPayload = void 0;
const Router = require("@koa/router");
const request_validator_1 = require("../middlewares/request-validator");
const response_validator_1 = require("../middlewares/response-validator");
const path_1 = require("path");
var ERouteControllerActionPayload;
(function (ERouteControllerActionPayload) {
    ERouteControllerActionPayload["QUERY"] = "query";
    ERouteControllerActionPayload["BODY"] = "body";
    ERouteControllerActionPayload["PATH"] = "path";
})(ERouteControllerActionPayload = exports.ERouteControllerActionPayload || (exports.ERouteControllerActionPayload = {}));
var ERouteControllerActionMethod;
(function (ERouteControllerActionMethod) {
    ERouteControllerActionMethod["GET"] = "get";
    ERouteControllerActionMethod["POST"] = "post";
    ERouteControllerActionMethod["DELETE"] = "delete";
})(ERouteControllerActionMethod = exports.ERouteControllerActionMethod || (exports.ERouteControllerActionMethod = {}));
function isRouteController(object) {
    return object.hasOwnProperty('actions');
}
function getControllerActionRouter(app, action) {
    const router = new Router();
    router[action.method](action.path, (0, request_validator_1.RequestValidator)(action.RequestDTO, action.payload), (ctx, next) => __awaiter(this, void 0, void 0, function* () {
        const data = yield action.Handler(app)(ctx);
        if (data !== undefined) {
            ctx.status = 200;
            ctx.body = { data };
        }
        else {
            ctx.status = 204;
            ctx.body = undefined;
        }
        yield next();
    }), (0, response_validator_1.ResponseValidator)(action.ResponseDTO));
    return router;
}
exports.getControllerActionRouter = getControllerActionRouter;
function registerControllerRoutes(app, controller, mainRouter, path = '/') {
    for (const item of controller.actions) {
        if (isRouteController(item)) {
            registerControllerRoutes(app, item, mainRouter, item.path === '/' ? path : path_1.posix.join(path, item.path));
        }
        else {
            const router = getControllerActionRouter(app, item);
            mainRouter.use(path, router.routes());
        }
    }
}
exports.registerControllerRoutes = registerControllerRoutes;
function getApplicationRouter(app, controllers) {
    const applicationRouter = new Router();
    for (const controller of controllers) {
        registerControllerRoutes(app, controller, applicationRouter, controller.path);
    }
    return applicationRouter;
}
exports.getApplicationRouter = getApplicationRouter;
//# sourceMappingURL=routing.js.map