"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.HashTimeSeries = void 0;
const time_series_1 = require("./time-series");
const redis_smq_common_1 = require("redis-smq-common");
class HashTimeSeries extends time_series_1.TimeSeries {
    constructor(redisClient, params) {
        super(redisClient, params);
        const { indexKey } = params;
        this.indexKey = indexKey;
    }
    add(ts, value, mixed) {
        const process = (multi) => {
            multi.hincrby(this.key, String(ts), value);
            multi.zadd(this.indexKey, ts, `${ts}`);
            if (this.expireAfter) {
                multi.expire(this.key, this.expireAfter);
                multi.expire(this.indexKey, this.expireAfter);
            }
        };
        if (typeof mixed === 'function') {
            const multi = this.redisClient.multi();
            process(multi);
            multi.exec((err) => mixed(err));
        }
        else
            process(mixed);
    }
    cleanUp(cb) {
        const ts = time_series_1.TimeSeries.getCurrentTimestamp();
        const max = ts - this.retentionTime;
        this.redisClient.zrangebyscore(this.indexKey, '-inf', `${max}`, (err, reply) => {
            if (err)
                cb(err);
            else if (reply && reply.length) {
                const multi = this.redisClient.multi();
                multi.zrem(this.indexKey, reply);
                multi.hdel(this.key, reply);
                multi.exec((err) => cb(err));
            }
            else
                cb();
        });
    }
    getRange(from, to, cb) {
        if (to <= from) {
            cb(new redis_smq_common_1.errors.ArgumentError(`Expected parameter [to] to be greater than [from]`));
        }
        else {
            const length = to - from;
            const timestamps = new Array(length)
                .fill(0)
                .map((_, index) => String(from + index));
            this.redisClient.hmget(this.key, timestamps, (err, reply) => {
                if (err)
                    cb(err);
                else {
                    const replyRange = reply !== null && reply !== void 0 ? reply : [];
                    const range = timestamps.map((i, index) => {
                        var _a;
                        return ({
                            timestamp: Number(i),
                            value: Number((_a = replyRange[index]) !== null && _a !== void 0 ? _a : 0),
                        });
                    });
                    cb(null, range);
                }
            });
        }
    }
}
exports.HashTimeSeries = HashTimeSeries;
//# sourceMappingURL=hash-time-series.js.map