"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MessageRate = void 0;
const events_1 = require("events");
const time_series_1 = require("./time-series");
const redis_smq_common_1 = require("redis-smq-common");
const redis_smq_1 = require("redis-smq");
class MessageRate extends events_1.EventEmitter {
    constructor(messageRateWriter) {
        super();
        this.onTick = () => {
            const ts = time_series_1.TimeSeries.getCurrentTimestamp();
            const rates = this.getRateFields();
            this.messageRateWriter.onRateTick(ts, rates);
        };
        this.readerTicker = new redis_smq_common_1.Ticker(this.onTick);
        this.readerTicker.runTimer();
        this.messageRateWriter = messageRateWriter;
    }
    quit(cb) {
        redis_smq_common_1.async.waterfall([
            (cb) => {
                this.readerTicker.once(redis_smq_1.events.DOWN, cb);
                this.readerTicker.quit();
            },
            (cb) => this.messageRateWriter.quit(cb),
        ], cb);
    }
}
exports.MessageRate = MessageRate;
//# sourceMappingURL=message-rate.js.map