"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SortedSetTimeSeries = void 0;
const time_series_1 = require("./time-series");
const redis_smq_common_1 = require("redis-smq-common");
class SortedSetTimeSeries extends time_series_1.TimeSeries {
    add(ts, value, mixed) {
        const process = (multi) => {
            multi.zadd(this.key, ts, `${value}:${ts}`);
            this.expireAfter && multi.pexpire(this.key, this.expireAfter * 1000);
        };
        if (typeof mixed === 'function') {
            const multi = this.redisClient.multi();
            process(multi);
            multi.exec((err) => mixed(err));
        }
        else
            process(mixed);
    }
    cleanUp(cb) {
        const ts = time_series_1.TimeSeries.getCurrentTimestamp();
        const max = ts - this.retentionTime;
        this.redisClient.zremrangebyscore(this.key, '-inf', `${max}`, (err) => cb(err));
    }
    getRange(from, to, cb) {
        if (to <= from) {
            cb(new redis_smq_common_1.errors.ArgumentError(`Expected parameter [to] to be greater than [from]`));
        }
        else {
            this.redisClient.zrangebyscorewithscores(this.key, from, to, (err, reply) => {
                if (err)
                    cb(err);
                else {
                    const replyRange = reply !== null && reply !== void 0 ? reply : {};
                    const length = to - from;
                    const range = new Array(length)
                        .fill(0)
                        .map((_, index) => {
                        const timestamp = from + index;
                        const value = typeof replyRange[timestamp] === 'string'
                            ? Number(replyRange[timestamp].split(':')[0])
                            : 0;
                        return {
                            timestamp,
                            value,
                        };
                    });
                    cb(null, range);
                }
            });
        }
    }
}
exports.SortedSetTimeSeries = SortedSetTimeSeries;
//# sourceMappingURL=sorted-set-time-series.js.map