/// <reference types="node" />
import { EventEmitter } from 'events';
import { RedisClient } from 'redis-smq-common';
import { TTimeSeriesParams, TTimeSeriesRange } from '../../../../types';
import { ICallback, IRedisClientMulti } from 'redis-smq-common/dist/types';
export declare abstract class TimeSeries<TimeSeriesParams extends TTimeSeriesParams> extends EventEmitter {
    protected retentionTime: number;
    protected expireAfter: number;
    protected windowSize: number;
    protected redisClient: RedisClient;
    protected key: string;
    constructor(redisClient: RedisClient, params: TimeSeriesParams);
    setWindowSize(windowSizeInSeconds: number): void;
    setRetentionTime(retentionTimeInSeconds: number): void;
    setExpiration(expireAfterInSeconds: number): void;
    abstract add(ts: number, value: number, cb: ICallback<void> | IRedisClientMulti): void;
    abstract getRange(from: number, to: number, cb: ICallback<TTimeSeriesRange>): void;
    abstract cleanUp(cb: ICallback<void>): void;
    getRangeFrom(from: number, cb: ICallback<TTimeSeriesRange>): void;
    static getCurrentTimestamp(): number;
}
