"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TimeSeries = void 0;
const events_1 = require("events");
const redis_smq_common_1 = require("redis-smq-common");
class TimeSeries extends events_1.EventEmitter {
    constructor(redisClient, params) {
        super();
        this.retentionTime = 24 * 60 * 60;
        this.expireAfter = 0;
        this.windowSize = 60;
        const { key, expireAfterInSeconds, retentionTimeInSeconds, windowSizeInSeconds, } = params;
        this.redisClient = redisClient;
        if (expireAfterInSeconds !== undefined)
            this.setExpiration(expireAfterInSeconds);
        if (retentionTimeInSeconds !== undefined)
            this.setRetentionTime(retentionTimeInSeconds);
        if (windowSizeInSeconds !== undefined)
            this.setWindowSize(windowSizeInSeconds);
        this.key = key;
    }
    setWindowSize(windowSizeInSeconds) {
        if (windowSizeInSeconds < 1) {
            throw new redis_smq_common_1.errors.ArgumentError('Expected a positive integer value in milliseconds >= 1');
        }
        this.windowSize = windowSizeInSeconds;
    }
    setRetentionTime(retentionTimeInSeconds) {
        if (retentionTimeInSeconds < 1) {
            throw new redis_smq_common_1.errors.ArgumentError('Expected a positive integer value in milliseconds >= 1');
        }
        this.retentionTime = retentionTimeInSeconds;
    }
    setExpiration(expireAfterInSeconds) {
        if (expireAfterInSeconds < 0) {
            throw new redis_smq_common_1.errors.ArgumentError('Expected a positive integer value in milliseconds');
        }
        this.expireAfter = expireAfterInSeconds;
    }
    getRangeFrom(from, cb) {
        const max = from;
        const min = from - this.windowSize;
        this.getRange(min, max, cb);
    }
    static getCurrentTimestamp() {
        return Math.ceil(Date.now() / 1000);
    }
}
exports.TimeSeries = TimeSeries;
//# sourceMappingURL=time-series.js.map