"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ConsumerMessageRateWriter = void 0;
const consumer_acknowledged_time_series_1 = require("./consumer-acknowledged-time-series");
const consumer_dead_lettered_time_series_1 = require("./consumer-dead-lettered-time-series");
const queue_acknowledged_time_series_1 = require("./queue-acknowledged-time-series");
const queue_dead_lettered_time_series_1 = require("./queue-dead-lettered-time-series");
const global_acknowledged_time_series_1 = require("./global-acknowledged-time-series");
const global_dead_lettered_time_series_1 = require("./global-dead-lettered-time-series");
const message_rate_writer_1 = require("../common/message-rate-writer");
class ConsumerMessageRateWriter extends message_rate_writer_1.MessageRateWriter {
    constructor(redisClient, queue, consumerId) {
        super();
        this.redisClient = redisClient;
        this.globalAcknowledgedRateTimeSeries =
            (0, global_acknowledged_time_series_1.GlobalAcknowledgedTimeSeries)(redisClient);
        this.globalDeadLetteredTimeSeries =
            (0, global_dead_lettered_time_series_1.GlobalDeadLetteredTimeSeries)(redisClient);
        this.acknowledgedTimeSeries = (0, consumer_acknowledged_time_series_1.ConsumerAcknowledgedTimeSeries)(redisClient, consumerId);
        this.deadLetteredTimeSeries = (0, consumer_dead_lettered_time_series_1.ConsumerDeadLetteredTimeSeries)(redisClient, consumerId);
        this.queueAcknowledgedRateTimeSeries = (0, queue_acknowledged_time_series_1.QueueAcknowledgedTimeSeries)(redisClient, queue);
        this.queueDeadLetteredTimeSeries = (0, queue_dead_lettered_time_series_1.QueueDeadLetteredTimeSeries)(redisClient, queue);
    }
    onUpdate(ts, rates, cb) {
        let multi = null;
        for (const field in rates) {
            multi = multi !== null && multi !== void 0 ? multi : this.redisClient.multi();
            const value = rates[field];
            if (value) {
                if (field === 'acknowledgedRate') {
                    this.acknowledgedTimeSeries.add(ts, value, multi);
                    this.queueAcknowledgedRateTimeSeries.add(ts, value, multi);
                    this.globalAcknowledgedRateTimeSeries.add(ts, value, multi);
                }
                else {
                    this.deadLetteredTimeSeries.add(ts, value, multi);
                    this.queueDeadLetteredTimeSeries.add(ts, value, multi);
                    this.globalDeadLetteredTimeSeries.add(ts, value, multi);
                }
            }
        }
        if (multi)
            multi.exec(() => cb());
        else
            cb();
    }
}
exports.ConsumerMessageRateWriter = ConsumerMessageRateWriter;
//# sourceMappingURL=consumer-message-rate-writer.js.map