"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProducerEventListener = void 0;
const producer_message_rate_1 = require("./producer/producer-message-rate");
const producer_message_rate_writer_1 = require("./producer/producer-message-rate-writer");
const redis_smq_1 = require("redis-smq");
const redis_smq_common_1 = require("redis-smq-common");
class ProducerEventListener {
    constructor() {
        this.producerMessageRate = null;
        this.redisClient = null;
        this.eventProvider = null;
        this.onMessagePublished = (message) => {
            var _a;
            (_a = this.producerMessageRate) === null || _a === void 0 ? void 0 : _a.incrementPublished(message.getDestinationQueue());
        };
    }
    init(args, cb) {
        const { config, eventProvider } = args;
        this.eventProvider = eventProvider;
        (0, redis_smq_common_1.createClientInstance)(config.redis, (err, redisClient) => {
            if (err)
                cb(err);
            else if (!redisClient)
                cb(new redis_smq_common_1.errors.EmptyCallbackReplyError());
            else {
                this.redisClient = redisClient;
                const writer = new producer_message_rate_writer_1.ProducerMessageRateWriter(redisClient);
                this.producerMessageRate = new producer_message_rate_1.ProducerMessageRate(writer);
                eventProvider.on(redis_smq_1.events.MESSAGE_PUBLISHED, this.onMessagePublished);
                cb();
            }
        });
    }
    quit(cb) {
        var _a;
        (_a = this.eventProvider) === null || _a === void 0 ? void 0 : _a.removeListener(redis_smq_1.events.MESSAGE_PUBLISHED, this.onMessagePublished);
        redis_smq_common_1.async.waterfall([
            (cb) => {
                if (this.producerMessageRate)
                    this.producerMessageRate.quit(cb);
                else
                    cb();
            },
            (cb) => {
                if (this.redisClient)
                    this.redisClient.halt(cb);
                else
                    cb();
            },
        ], cb);
    }
}
exports.ProducerEventListener = ProducerEventListener;
//# sourceMappingURL=producer-event-listener.js.map