"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProducerMessageRateWriter = void 0;
const message_rate_writer_1 = require("../common/message-rate-writer");
const global_published_time_series_1 = require("./global-published-time-series");
const queue_published_time_series_1 = require("./queue-published-time-series");
class ProducerMessageRateWriter extends message_rate_writer_1.MessageRateWriter {
    constructor(redisClient) {
        super();
        this.queuePublishedTimeSeries = {};
        this.redisClient = redisClient;
        this.globalPublishedTimeSeries = (0, global_published_time_series_1.GlobalPublishedTimeSeries)(redisClient);
    }
    onUpdate(ts, rates, cb) {
        const { publishedRate, queuePublishedRate } = rates;
        if (Object.keys(queuePublishedRate).length) {
            if (publishedRate) {
                const multi = this.redisClient.multi();
                this.globalPublishedTimeSeries.add(ts, publishedRate, multi);
                for (const key in queuePublishedRate) {
                    const value = queuePublishedRate[key];
                    if (value) {
                        if (!this.queuePublishedTimeSeries[key]) {
                            const [ns, name] = key.split(':');
                            this.queuePublishedTimeSeries[key] = (0, queue_published_time_series_1.QueuePublishedTimeSeries)(this.redisClient, { ns, name });
                        }
                        this.queuePublishedTimeSeries[key].add(ts, value, multi);
                    }
                }
                multi.exec(() => cb());
            }
            else
                cb();
        }
        else
            cb();
    }
}
exports.ProducerMessageRateWriter = ProducerMessageRateWriter;
//# sourceMappingURL=producer-message-rate-writer.js.map