import { FanOutExchange, FanOutExchangeManager } from 'redis-smq';
import { TRegistry } from '../lib/registry';
import { TQueueParams } from 'redis-smq/dist/types';
import { GetExchangeQueuesRequestDTO } from '../controllers/api/exchanges/get-exchange-queues/get-exchange-queues.request.DTO';
import { BindQueueRequestDTO } from '../controllers/api/exchanges/bind-queue/bind-queue.request.DTO';
import { CreateExchangeRequestDTO } from '../controllers/api/exchanges/create-exchange/create-exchange.request.DTO';
import { DeleteExchangeRequestDTO } from '../controllers/api/exchanges/delete-exchange/delete-exchange.request.DTO';
export declare class ExchangesService {
    protected static instance: ExchangesService | null;
    protected fanOutExchangeManager: {
        createExchangeAsync: (exchange: FanOutExchange) => Promise<void>;
        deleteExchangeAsync: (exchange: FanOutExchange) => Promise<void>;
        bindQueueAsync: (queue: string | TQueueParams, exchange: FanOutExchange) => Promise<void>;
        unbindQueueAsync: (queue: string | TQueueParams, exchange: FanOutExchange) => Promise<void>;
        getExchangesAsync: () => Promise<string[]>;
        getExchangeQueuesAsync: (exchange: FanOutExchange) => Promise<TQueueParams[]>;
        getQueueExchangeAsync: ((queue: string | TQueueParams) => Promise<null>) | ((queue: string | TQueueParams) => Promise<FanOutExchange>);
        quitAsync: () => Promise<void>;
    } & FanOutExchangeManager;
    protected constructor(fanOutExchangeManager: FanOutExchangeManager);
    getExchanges(): Promise<string[]>;
    getExchangeQueues({ exchangeName, }: GetExchangeQueuesRequestDTO): Promise<TQueueParams[]>;
    bindQueue({ exchangeName, queue }: BindQueueRequestDTO): Promise<void>;
    unbindQueue({ exchangeName, queue, }: BindQueueRequestDTO): Promise<void>;
    createExchange({ exchangeName, }: CreateExchangeRequestDTO): Promise<string[]>;
    deleteExchange({ exchangeName, }: DeleteExchangeRequestDTO): Promise<string[]>;
    static getInstance(registry: TRegistry): Promise<ExchangesService>;
}
