"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ExchangesService = void 0;
const bluebird_1 = require("bluebird");
const redis_smq_1 = require("redis-smq");
const fan_out_exchange_manager_1 = require("../lib/fan-out-exchange-manager");
class ExchangesService {
    constructor(fanOutExchangeManager) {
        this.fanOutExchangeManager = (0, bluebird_1.promisifyAll)(fanOutExchangeManager);
    }
    getExchanges() {
        return __awaiter(this, void 0, void 0, function* () {
            return this.fanOutExchangeManager.getExchangesAsync();
        });
    }
    getExchangeQueues({ exchangeName, }) {
        return __awaiter(this, void 0, void 0, function* () {
            const e = new redis_smq_1.FanOutExchange(exchangeName);
            return this.fanOutExchangeManager.getExchangeQueuesAsync(e);
        });
    }
    bindQueue({ exchangeName, queue }) {
        return __awaiter(this, void 0, void 0, function* () {
            const e = new redis_smq_1.FanOutExchange(exchangeName);
            return this.fanOutExchangeManager.bindQueueAsync(queue, e);
        });
    }
    unbindQueue({ exchangeName, queue, }) {
        return __awaiter(this, void 0, void 0, function* () {
            const e = new redis_smq_1.FanOutExchange(exchangeName);
            return this.fanOutExchangeManager.unbindQueueAsync(queue, e);
        });
    }
    createExchange({ exchangeName, }) {
        return __awaiter(this, void 0, void 0, function* () {
            const e = new redis_smq_1.FanOutExchange(exchangeName);
            yield this.fanOutExchangeManager.createExchangeAsync(e);
            return this.fanOutExchangeManager.getExchangesAsync();
        });
    }
    deleteExchange({ exchangeName, }) {
        return __awaiter(this, void 0, void 0, function* () {
            const e = new redis_smq_1.FanOutExchange(exchangeName);
            yield this.fanOutExchangeManager.deleteExchangeAsync(e);
            return this.fanOutExchangeManager.getExchangesAsync();
        });
    }
    static getInstance(registry) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!ExchangesService.instance) {
                const config = registry.getItem('config');
                const instance = yield (0, fan_out_exchange_manager_1.getFanOutExchangeManagerInstance)(config);
                ExchangesService.instance = new ExchangesService(instance);
            }
            return ExchangesService.instance;
        });
    }
}
exports.ExchangesService = ExchangesService;
ExchangesService.instance = null;
//# sourceMappingURL=exchanges.service.js.map