import { GetScheduledMessagesRequestDTO } from '../controllers/api/main/scheduled-messages/get-scheduled-messages/get-scheduled-messages.request.DTO';
import { GetPendingMessagesRequestDTO } from '../controllers/api/namespaces/queue/pending-messages/get-pending-messages/get-pending-messages.request.DTO';
import { GetAcknowledgedMessagesRequestDTO } from '../controllers/api/namespaces/queue/acknowledged-messages/get-acknowledged-messages/get-acknowledged-messages.request.DTO';
import { GetDeadLetteredMessagesRequestDTO } from '../controllers/api/namespaces/queue/dead-lettered-messages/get-dead-lettered-messages/get-dead-lettered-messages.request.DTO';
import { DeletePendingMessageRequestDTO } from '../controllers/api/namespaces/queue/pending-messages/delete-pending-message/delete-pending-message.request.DTO';
import { DeleteAcknowledgedMessageRequestDTO } from '../controllers/api/namespaces/queue/acknowledged-messages/delete-acknowledged-message/delete-acknowledged-message.request.DTO';
import { DeleteDeadLetteredMessageRequestDTO } from '../controllers/api/namespaces/queue/dead-lettered-messages/delete-dead-lettered-message/delete-dead-lettered-message.request.DTO';
import { DeleteScheduledMessageRequestDTO } from '../controllers/api/main/scheduled-messages/delete-scheduled-message/delete-scheduled-message-request.DTO';
import { RequeueDeadLetteredMessageRequestDTO } from '../controllers/api/namespaces/queue/dead-lettered-messages/requeue-dead-lettered-message/requeue-dead-lettered-message.request.DTO';
import { RequeueAcknowledgedMessageRequestDTO } from '../controllers/api/namespaces/queue/acknowledged-messages/requeue-acknowledged-message/requeue-acknowledged-message.request.DTO';
import { PurgeDeadLetteredMessagesRequestDTO } from '../controllers/api/namespaces/queue/dead-lettered-messages/purge-dead-lettered-messages/purge-dead-lettered-messages.request.DTO';
import { PurgeAcknowledgedMessagesRequestDTO } from '../controllers/api/namespaces/queue/acknowledged-messages/purge-acknowledged-messages/purge-acknowledged-messages.request.DTO';
import { PurgePendingMessagesRequestDTO } from '../controllers/api/namespaces/queue/pending-messages/purge-pending-messages/purge-pending-messages.request.DTO';
import { MessageManager } from 'redis-smq';
import { TRegistry } from '../lib/registry';
export declare class MessagesService {
    protected static instance: MessagesService | null;
    protected scheduledMessages: {
        deleteAsync: (messageId: string) => Promise<void>;
        purgeAsync: () => Promise<void>;
        listAsync: (skip: number, take: number) => Promise<import("redis-smq/dist/types").TGetMessagesReply>;
        countAsync: () => Promise<number>;
    } & import("redis-smq/dist/src/lib/message-manager/scheduled-messages").ScheduledMessages;
    protected acknowledgedMessages: {
        listAsync: (queue: string | import("redis-smq/dist/types").TQueueParams, skip: number, take: number) => Promise<import("redis-smq/dist/types").TGetMessagesReply>;
        purgeAsync: (queue: string | import("redis-smq/dist/types").TQueueParams) => Promise<void>;
        requeueAsync: (queue: string | import("redis-smq/dist/types").TQueueParams, messageId: string, sequenceId: number) => Promise<void>;
        deleteAsync: (queue: string | import("redis-smq/dist/types").TQueueParams, messageId: string, sequenceId: number) => Promise<void>;
        countAsync: (queue: string | import("redis-smq/dist/types").TQueueParams) => Promise<number>;
    } & import("redis-smq/dist/src/lib/message-manager/acknowledged-messages").AcknowledgedMessages;
    protected pendingMessages: {
        purgeAsync: (queue: string | import("redis-smq/dist/types").TQueueParams) => Promise<void>;
        listAsync: (queue: string | import("redis-smq/dist/types").TQueueParams, skip: number, take: number) => Promise<import("redis-smq/dist/types").TGetMessagesReply>;
        deleteAsync: (queue: string | import("redis-smq/dist/types").TQueueParams, messageId: string, sequenceId: number) => Promise<void>;
        countAsync: (queue: string | import("redis-smq/dist/types").TQueueParams) => Promise<number>;
    } & import("redis-smq/dist/src/lib/message-manager/pending-messages").PendingMessages;
    protected deadLetteredMessages: {
        purgeAsync: (queue: string | import("redis-smq/dist/types").TQueueParams) => Promise<void>;
        requeueAsync: (queue: string | import("redis-smq/dist/types").TQueueParams, messageId: string, sequenceId: number) => Promise<void>;
        deleteAsync: (queue: string | import("redis-smq/dist/types").TQueueParams, messageId: string, sequenceId: number) => Promise<void>;
        listAsync: (queue: string | import("redis-smq/dist/types").TQueueParams, skip: number, take: number) => Promise<import("redis-smq/dist/types").TGetMessagesReply>;
        countAsync: (queue: string | import("redis-smq/dist/types").TQueueParams) => Promise<number>;
    } & import("redis-smq/dist/src/lib/message-manager/dead-lettered-messages").DeadLetteredMessages;
    protected constructor(messageManager: MessageManager);
    getScheduledMessages(args: GetScheduledMessagesRequestDTO): Promise<{
        items: {
            message: import("redis-smq/dist/types").TMessageJSON;
            sequenceId: number;
        }[];
        total: number;
    }>;
    getPendingMessages(args: GetPendingMessagesRequestDTO): Promise<{
        items: {
            message: import("redis-smq/dist/types").TMessageJSON;
            sequenceId: number;
        }[];
        total: number;
    }>;
    getAcknowledgedMessages(args: GetAcknowledgedMessagesRequestDTO): Promise<{
        items: {
            message: import("redis-smq/dist/types").TMessageJSON;
            sequenceId: number;
        }[];
        total: number;
    }>;
    getDeadLetteredMessages(args: GetDeadLetteredMessagesRequestDTO): Promise<{
        items: {
            message: import("redis-smq/dist/types").TMessageJSON;
            sequenceId: number;
        }[];
        total: number;
    }>;
    deletePendingMessage(args: DeletePendingMessageRequestDTO): Promise<void>;
    deleteAcknowledgedMessage(args: DeleteAcknowledgedMessageRequestDTO): Promise<void>;
    deleteDeadLetteredMessage(args: DeleteDeadLetteredMessageRequestDTO): Promise<void>;
    deleteScheduledMessage(args: DeleteScheduledMessageRequestDTO): Promise<void>;
    requeueDeadLetteredMessage(args: RequeueDeadLetteredMessageRequestDTO): Promise<void>;
    requeueAcknowledgedMessage(args: RequeueAcknowledgedMessageRequestDTO): Promise<void>;
    purgeDeadLetteredMessages(args: PurgeDeadLetteredMessagesRequestDTO): Promise<void>;
    purgeAcknowledgedMessages(args: PurgeAcknowledgedMessagesRequestDTO): Promise<void>;
    purgePendingMessages(args: PurgePendingMessagesRequestDTO): Promise<void>;
    purgeScheduledMessages(): Promise<void>;
    static getInstance(registry: TRegistry): Promise<MessagesService>;
}
