"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MessagesService = void 0;
const bluebird_1 = require("bluebird");
const message_manager_1 = require("../lib/message-manager");
class MessagesService {
    constructor(messageManager) {
        this.scheduledMessages = (0, bluebird_1.promisifyAll)(messageManager.scheduledMessages);
        this.acknowledgedMessages = (0, bluebird_1.promisifyAll)(messageManager.acknowledgedMessages);
        this.pendingMessages = (0, bluebird_1.promisifyAll)(messageManager.pendingMessages);
        this.deadLetteredMessages = (0, bluebird_1.promisifyAll)(messageManager.deadLetteredMessages);
    }
    getScheduledMessages(args) {
        return __awaiter(this, void 0, void 0, function* () {
            const { skip = 0, take = 1 } = args;
            const r = yield this.scheduledMessages.listAsync(skip, take);
            return Object.assign(Object.assign({}, r), { items: r.items.map((i) => (Object.assign(Object.assign({}, i), { message: i.message.toJSON() }))) });
        });
    }
    getPendingMessages(args) {
        return __awaiter(this, void 0, void 0, function* () {
            const { ns, queueName, skip = 0, take = 1 } = args;
            const r = yield this.pendingMessages.listAsync({
                name: queueName,
                ns,
            }, skip, take);
            return Object.assign(Object.assign({}, r), { items: r.items.map((i) => (Object.assign(Object.assign({}, i), { message: i.message.toJSON() }))) });
        });
    }
    getAcknowledgedMessages(args) {
        return __awaiter(this, void 0, void 0, function* () {
            const { ns, queueName, skip = 0, take = 1 } = args;
            const r = yield this.acknowledgedMessages.listAsync({
                name: queueName,
                ns,
            }, skip, take);
            return Object.assign(Object.assign({}, r), { items: r.items.map((i) => (Object.assign(Object.assign({}, i), { message: i.message.toJSON() }))) });
        });
    }
    getDeadLetteredMessages(args) {
        return __awaiter(this, void 0, void 0, function* () {
            const { ns, queueName, skip = 0, take = 1 } = args;
            const r = yield this.deadLetteredMessages.listAsync({
                name: queueName,
                ns,
            }, skip, take);
            return Object.assign(Object.assign({}, r), { items: r.items.map((i) => (Object.assign(Object.assign({}, i), { message: i.message.toJSON() }))) });
        });
    }
    deletePendingMessage(args) {
        return __awaiter(this, void 0, void 0, function* () {
            const { ns, queueName, id, sequenceId } = args;
            return this.pendingMessages.deleteAsync({
                name: queueName,
                ns,
            }, id, sequenceId);
        });
    }
    deleteAcknowledgedMessage(args) {
        return __awaiter(this, void 0, void 0, function* () {
            const { ns, queueName, id, sequenceId } = args;
            return this.acknowledgedMessages.deleteAsync({
                name: queueName,
                ns,
            }, id, sequenceId);
        });
    }
    deleteDeadLetteredMessage(args) {
        return __awaiter(this, void 0, void 0, function* () {
            const { ns, queueName, id, sequenceId } = args;
            return this.deadLetteredMessages.deleteAsync({
                name: queueName,
                ns,
            }, id, sequenceId);
        });
    }
    deleteScheduledMessage(args) {
        return __awaiter(this, void 0, void 0, function* () {
            const { id } = args;
            return this.scheduledMessages.deleteAsync(id);
        });
    }
    requeueDeadLetteredMessage(args) {
        return __awaiter(this, void 0, void 0, function* () {
            const { ns, queueName, id, sequenceId } = args;
            return this.deadLetteredMessages.requeueAsync({
                name: queueName,
                ns,
            }, id, sequenceId);
        });
    }
    requeueAcknowledgedMessage(args) {
        return __awaiter(this, void 0, void 0, function* () {
            const { ns, queueName, id, sequenceId } = args;
            return this.acknowledgedMessages.requeueAsync({
                name: queueName,
                ns,
            }, id, sequenceId);
        });
    }
    purgeDeadLetteredMessages(args) {
        return __awaiter(this, void 0, void 0, function* () {
            const { ns, queueName } = args;
            return this.deadLetteredMessages.purgeAsync({
                name: queueName,
                ns,
            });
        });
    }
    purgeAcknowledgedMessages(args) {
        return __awaiter(this, void 0, void 0, function* () {
            const { ns, queueName } = args;
            return this.acknowledgedMessages.purgeAsync({
                name: queueName,
                ns,
            });
        });
    }
    purgePendingMessages(args) {
        return __awaiter(this, void 0, void 0, function* () {
            const { ns, queueName } = args;
            return this.pendingMessages.purgeAsync({
                name: queueName,
                ns,
            });
        });
    }
    purgeScheduledMessages() {
        return __awaiter(this, void 0, void 0, function* () {
            return this.scheduledMessages.purgeAsync();
        });
    }
    static getInstance(registry) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!MessagesService.instance) {
                const config = registry.getItem('config');
                const messageManager = yield (0, message_manager_1.getMessageManagerInstance)(config);
                MessagesService.instance = new MessagesService(messageManager);
            }
            return MessagesService.instance;
        });
    }
}
exports.MessagesService = MessagesService;
MessagesService.instance = null;
//# sourceMappingURL=messages.service.js.map