"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.QueueTimeSeriesService = void 0;
const bluebird_1 = require("bluebird");
const queue_acknowledged_time_series_1 = require("../event-listeners/message-rate/consumer/queue-acknowledged-time-series");
const queue_dead_lettered_time_series_1 = require("../event-listeners/message-rate/consumer/queue-dead-lettered-time-series");
const queue_published_time_series_1 = require("../event-listeners/message-rate/producer/queue-published-time-series");
class QueueTimeSeriesService {
    constructor(redisClient) {
        this.redisClient = redisClient;
    }
    acknowledged(args) {
        return __awaiter(this, void 0, void 0, function* () {
            const { ns, queueName, from, to } = args;
            const timeSeries = (0, bluebird_1.promisifyAll)((0, queue_acknowledged_time_series_1.QueueAcknowledgedTimeSeries)(this.redisClient, {
                name: queueName,
                ns,
            }));
            return timeSeries.getRangeAsync(from, to);
        });
    }
    deadLettered(args) {
        return __awaiter(this, void 0, void 0, function* () {
            const { ns, queueName, from, to } = args;
            const timeSeries = (0, bluebird_1.promisifyAll)((0, queue_dead_lettered_time_series_1.QueueDeadLetteredTimeSeries)(this.redisClient, {
                name: queueName,
                ns,
            }));
            return timeSeries.getRangeAsync(from, to);
        });
    }
    published(args) {
        return __awaiter(this, void 0, void 0, function* () {
            const { ns, queueName, from, to } = args;
            const timeSeries = (0, bluebird_1.promisifyAll)((0, queue_published_time_series_1.QueuePublishedTimeSeries)(this.redisClient, {
                name: queueName,
                ns,
            }));
            return timeSeries.getRangeAsync(from, to);
        });
    }
    static getInstance(registry) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!QueueTimeSeriesService.instance) {
                const redis = registry.getItem('redis');
                QueueTimeSeriesService.instance = new QueueTimeSeriesService(redis);
            }
            return QueueTimeSeriesService.instance;
        });
    }
}
exports.QueueTimeSeriesService = QueueTimeSeriesService;
QueueTimeSeriesService.instance = null;
//# sourceMappingURL=queue-time-series.service.js.map