"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.QueuesService = void 0;
const bluebird_1 = require("bluebird");
const queue_manager_1 = require("../lib/queue-manager");
class QueuesService {
    constructor(queueManager) {
        this.queue = (0, bluebird_1.promisifyAll)(queueManager.queue);
        this.namespace = (0, bluebird_1.promisifyAll)(queueManager.namespace);
        this.queueRateLimit = (0, bluebird_1.promisifyAll)(queueManager.queueRateLimit);
    }
    getNamespaces() {
        return __awaiter(this, void 0, void 0, function* () {
            return this.namespace.listAsync();
        });
    }
    createQueue(args) {
        return __awaiter(this, void 0, void 0, function* () {
            const { ns, name, enablePriorityQueuing } = args;
            const queueParams = ns && name ? { name, ns } : name;
            return this.queue.createAsync(queueParams, enablePriorityQueuing);
        });
    }
    getNamespaceQueues(args) {
        return __awaiter(this, void 0, void 0, function* () {
            const { ns } = args;
            return this.namespace.getQueuesAsync(ns);
        });
    }
    deleteNamespace(args) {
        return __awaiter(this, void 0, void 0, function* () {
            const { ns } = args;
            return this.namespace.deleteAsync(ns);
        });
    }
    getQueues() {
        return __awaiter(this, void 0, void 0, function* () {
            return this.queue.listAsync();
        });
    }
    deleteQueue(args) {
        return __awaiter(this, void 0, void 0, function* () {
            const { ns, queueName } = args;
            return this.queue.deleteAsync({
                name: queueName,
                ns,
            });
        });
    }
    setQueueRateLimit(args) {
        return __awaiter(this, void 0, void 0, function* () {
            const { ns, queueName, interval, limit } = args;
            return this.queueRateLimit.setAsync({ name: queueName, ns }, { interval, limit });
        });
    }
    clearQueueRateLimit(args) {
        return __awaiter(this, void 0, void 0, function* () {
            const { ns, queueName } = args;
            return this.queueRateLimit.clearAsync({
                name: queueName,
                ns,
            });
        });
    }
    getQueueRateLimit(args) {
        return __awaiter(this, void 0, void 0, function* () {
            const { ns, queueName } = args;
            return this.queueRateLimit.getAsync({ name: queueName, ns });
        });
    }
    static getInstance(registry) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!QueuesService.instance) {
                const config = registry.getItem('config');
                const queueManager = yield (0, queue_manager_1.getQueueManagerInstance)(config);
                QueuesService.instance = new QueuesService(queueManager);
            }
            return QueuesService.instance;
        });
    }
}
exports.QueuesService = QueuesService;
QueuesService.instance = null;
//# sourceMappingURL=queues.service.js.map