"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TimeSeriesCleanUpWorker = void 0;
const global_acknowledged_time_series_1 = require("../event-listeners/message-rate/consumer/global-acknowledged-time-series");
const global_published_time_series_1 = require("../event-listeners/message-rate/producer/global-published-time-series");
const global_dead_lettered_time_series_1 = require("../event-listeners/message-rate/consumer/global-dead-lettered-time-series");
const queue_acknowledged_time_series_1 = require("../event-listeners/message-rate/consumer/queue-acknowledged-time-series");
const queue_dead_lettered_time_series_1 = require("../event-listeners/message-rate/consumer/queue-dead-lettered-time-series");
const queue_published_time_series_1 = require("../event-listeners/message-rate/producer/queue-published-time-series");
const consumer_acknowledged_time_series_1 = require("../event-listeners/message-rate/consumer/consumer-acknowledged-time-series");
const consumer_dead_lettered_time_series_1 = require("../event-listeners/message-rate/consumer/consumer-dead-lettered-time-series");
const redis_smq_common_1 = require("redis-smq-common");
const redis_smq_1 = require("redis-smq");
class TimeSeriesCleanUpWorker extends redis_smq_common_1.Worker {
    constructor(redisClient, queueManager, managed) {
        super(managed);
        this.cleanUpGlobalTimeSeries = (cb) => {
            redis_smq_common_1.async.waterfall([
                (cb) => (0, global_acknowledged_time_series_1.GlobalAcknowledgedTimeSeries)(this.redisClient).cleanUp(cb),
                (cb) => (0, global_published_time_series_1.GlobalPublishedTimeSeries)(this.redisClient).cleanUp(cb),
                (cb) => (0, global_dead_lettered_time_series_1.GlobalDeadLetteredTimeSeries)(this.redisClient).cleanUp(cb),
            ], cb);
        };
        this.cleanUpQueueTimeSeries = (queues, cb) => {
            redis_smq_common_1.async.eachOf(queues, (queue, _, done) => {
                redis_smq_common_1.async.waterfall([
                    (cb) => (0, queue_acknowledged_time_series_1.QueueAcknowledgedTimeSeries)(this.redisClient, queue).cleanUp(cb),
                    (cb) => (0, queue_dead_lettered_time_series_1.QueueDeadLetteredTimeSeries)(this.redisClient, queue).cleanUp(cb),
                    (cb) => (0, queue_published_time_series_1.QueuePublishedTimeSeries)(this.redisClient, queue).cleanUp(cb),
                ], done);
            }, cb);
        };
        this.cleanUpConsumerTimeSeries = (consumerIds, queue, cb) => {
            redis_smq_common_1.async.eachOf(consumerIds, (consumerId, _, done) => {
                redis_smq_common_1.async.waterfall([
                    (cb) => (0, consumer_acknowledged_time_series_1.ConsumerAcknowledgedTimeSeries)(this.redisClient, consumerId).cleanUp(cb),
                    (cb) => (0, consumer_dead_lettered_time_series_1.ConsumerDeadLetteredTimeSeries)(this.redisClient, consumerId).cleanUp(cb),
                ], done);
            }, cb);
        };
        this.work = (cb) => {
            redis_smq_common_1.async.waterfall([
                (cb) => this.cleanUpGlobalTimeSeries(cb),
                (cb) => {
                    this.queueManager.queue.list((err, reply) => {
                        if (err)
                            cb(err);
                        else {
                            const queues = reply !== null && reply !== void 0 ? reply : [];
                            this.cleanUpQueueTimeSeries(queues, (err) => {
                                if (err)
                                    cb(err);
                                else
                                    cb(null, queues);
                            });
                        }
                    });
                },
                (queues, cb) => {
                    redis_smq_common_1.async.eachOf(queues, (queue, _, done) => {
                        redis_smq_1.Consumer.getOnlineConsumerIds(this.redisClient, queue, (err, reply) => {
                            if (err)
                                done(err);
                            else {
                                const consumerIds = reply !== null && reply !== void 0 ? reply : [];
                                this.cleanUpConsumerTimeSeries(consumerIds, queue, done);
                            }
                        });
                    }, cb);
                },
            ], cb);
        };
        this.queueManager = queueManager;
        this.redisClient = redisClient;
    }
}
exports.TimeSeriesCleanUpWorker = TimeSeriesCleanUpWorker;
exports.default = TimeSeriesCleanUpWorker;
//# sourceMappingURL=time-series.clean-up.worker.js.map