"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WebsocketRateStreamWorker = void 0;
const global_acknowledged_time_series_1 = require("../event-listeners/message-rate/consumer/global-acknowledged-time-series");
const global_published_time_series_1 = require("../event-listeners/message-rate/producer/global-published-time-series");
const global_dead_lettered_time_series_1 = require("../event-listeners/message-rate/consumer/global-dead-lettered-time-series");
const queue_acknowledged_time_series_1 = require("../event-listeners/message-rate/consumer/queue-acknowledged-time-series");
const queue_dead_lettered_time_series_1 = require("../event-listeners/message-rate/consumer/queue-dead-lettered-time-series");
const queue_published_time_series_1 = require("../event-listeners/message-rate/producer/queue-published-time-series");
const consumer_acknowledged_time_series_1 = require("../event-listeners/message-rate/consumer/consumer-acknowledged-time-series");
const consumer_dead_lettered_time_series_1 = require("../event-listeners/message-rate/consumer/consumer-dead-lettered-time-series");
const redis_smq_common_1 = require("redis-smq-common");
const redis_smq_1 = require("redis-smq");
class WebsocketRateStreamWorker extends redis_smq_common_1.Worker {
    constructor(redisClient, queueManager, managed) {
        super(managed);
        this.timestamp = 0;
        this.publishConsumerTimeSeries = (queue, consumerId, cb) => {
            redis_smq_common_1.async.waterfall([
                (cb) => (0, consumer_acknowledged_time_series_1.ConsumerAcknowledgedTimeSeries)(this.redisClient, consumerId).getRangeFrom(this.timestamp, (err, reply) => {
                    if (err)
                        cb(err);
                    else {
                        this.redisClient.publish(`streamConsumerAcknowledged:${consumerId}`, JSON.stringify(reply), () => cb());
                    }
                }),
                (cb) => (0, consumer_dead_lettered_time_series_1.ConsumerDeadLetteredTimeSeries)(this.redisClient, consumerId).getRangeFrom(this.timestamp, (err, reply) => {
                    if (err)
                        cb(err);
                    else {
                        this.redisClient.publish(`streamConsumerDeadLettered:${consumerId}`, JSON.stringify(reply), () => cb());
                    }
                }),
            ], cb);
        };
        this.publishQueueTimeSeries = (queue, cb) => {
            redis_smq_common_1.async.waterfall([
                (cb) => (0, queue_acknowledged_time_series_1.QueueAcknowledgedTimeSeries)(this.redisClient, queue).getRangeFrom(this.timestamp, (err, reply) => {
                    if (err)
                        cb(err);
                    else {
                        this.redisClient.publish(`streamQueueAcknowledged:${queue.ns}:${queue.name}`, JSON.stringify(reply), () => cb());
                    }
                }),
                (cb) => (0, queue_dead_lettered_time_series_1.QueueDeadLetteredTimeSeries)(this.redisClient, queue).getRangeFrom(this.timestamp, (err, reply) => {
                    if (err)
                        cb(err);
                    else {
                        this.redisClient.publish(`streamQueueDeadLettered:${queue.ns}:${queue.name}`, JSON.stringify(reply), () => cb());
                    }
                }),
                (cb) => (0, queue_published_time_series_1.QueuePublishedTimeSeries)(this.redisClient, queue).getRangeFrom(this.timestamp, (err, reply) => {
                    if (err)
                        cb(err);
                    else {
                        this.redisClient.publish(`streamQueuePublished:${queue.ns}:${queue.name}`, JSON.stringify(reply), () => cb());
                    }
                }),
            ], cb);
        };
        this.handleGlobalTimeSeries = (cb) => {
            redis_smq_common_1.async.waterfall([
                (cb) => (0, global_acknowledged_time_series_1.GlobalAcknowledgedTimeSeries)(this.redisClient).getRangeFrom(this.timestamp, (err, reply) => {
                    if (err)
                        cb(err);
                    else {
                        this.redisClient.publish('streamGlobalAcknowledged', JSON.stringify(reply), () => cb());
                    }
                }),
                (cb) => (0, global_dead_lettered_time_series_1.GlobalDeadLetteredTimeSeries)(this.redisClient).getRangeFrom(this.timestamp, (err, reply) => {
                    if (err)
                        cb(err);
                    else {
                        this.redisClient.publish('streamGlobalDeadLettered', JSON.stringify(reply), () => cb());
                    }
                }),
                (cb) => (0, global_published_time_series_1.GlobalPublishedTimeSeries)(this.redisClient).getRangeFrom(this.timestamp, (err, reply) => {
                    if (err)
                        cb(err);
                    else {
                        this.redisClient.publish('streamGlobalPublished', JSON.stringify(reply), () => cb());
                    }
                }),
            ], cb);
        };
        this.handleConsumersTimeSeries = (queues, cb) => {
            redis_smq_common_1.async.each(queues, (queueParams, idx, done) => {
                redis_smq_1.Consumer.getOnlineConsumerIds(this.redisClient, queueParams, (err, ids) => {
                    if (err)
                        done(err);
                    else {
                        redis_smq_common_1.async.each(ids !== null && ids !== void 0 ? ids : [], (consumerId, idx, done) => {
                            this.publishConsumerTimeSeries(queueParams, consumerId, done);
                        }, done);
                    }
                });
            }, cb);
        };
        this.handleQueuesTimeSeries = (cb) => {
            this.queueManager.queue.list((err, reply) => {
                if (err)
                    cb(err);
                else {
                    const queues = reply !== null && reply !== void 0 ? reply : [];
                    redis_smq_common_1.async.each(queues, (queue, index, done) => {
                        this.publishQueueTimeSeries(queue, done);
                    }, (err) => {
                        if (err)
                            cb(err);
                        else
                            cb(null, queues);
                    });
                }
            });
        };
        this.work = (cb) => {
            this.timestamp = Math.ceil(Date.now() / 1000);
            redis_smq_common_1.async.waterfall([
                this.handleGlobalTimeSeries,
                this.handleQueuesTimeSeries,
                this.handleConsumersTimeSeries,
            ], cb);
        };
        this.queueManager = queueManager;
        this.redisClient = redisClient;
    }
}
exports.WebsocketRateStreamWorker = WebsocketRateStreamWorker;
exports.default = WebsocketRateStreamWorker;
//# sourceMappingURL=websocket-rate-stream.worker.js.map